@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::tour_de_france;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 =encoding iso-8859-1
 
@@ -31,6 +31,7 @@ The winners from 1903 onwards are:
 
 =pod
 
+    2013   Chris Froome          GBR
     2012   Bradley Wiggins       GBR
     2011   Cadel Evans           AUS
     2010   Andy Schleck          LUX
@@ -153,6 +154,13 @@ Abigail
 
 =item *
 
+2013-07-22 - v1.004
+
+Updated with the winner of the 2013 edition,
+published in Acme-MetaSyntactic-Themes version 1.034.
+
+=item *
+
 2012-10-29 - v1.003
 
 Published in Acme-MetaSyntactic-Themes version 1.02.
